@@ -46,6 +46,9 @@ def column_types_probabilities(values, types=[], pos=None, key=None):
         'city',
         'region',
         'zipcode',
+        'phone',
+        'email',
+        'url',
         'country',
         'address',
         'text',
